summaryrefslogtreecommitdiffstats
path: root/ppapi/proxy/plugin_message_filter.h
diff options
context:
space:
mode:
Diffstat (limited to 'ppapi/proxy/plugin_message_filter.h')
-rw-r--r--ppapi/proxy/plugin_message_filter.h47
1 files changed, 37 insertions, 10 deletions
diff --git a/ppapi/proxy/plugin_message_filter.h b/ppapi/proxy/plugin_message_filter.h
index 5701a96..6469007 100644
--- a/ppapi/proxy/plugin_message_filter.h
+++ b/ppapi/proxy/plugin_message_filter.h
@@ -8,26 +8,37 @@
#include <set>
#include "base/compiler_specific.h"
+#include "base/memory/ref_counted.h"
#include "ipc/ipc_channel_proxy.h"
#include "ipc/ipc_sender.h"
#include "ppapi/c/pp_instance.h"
+#include "ppapi/proxy/ppapi_proxy_export.h"
namespace ppapi {
namespace proxy {
+class ResourceMessageReplyParams;
+class ResourceReplyThreadRegistrar;
+
// Listens for messages on the I/O thread of the plugin and handles some of
// them to avoid needing to block on the plugin.
//
// There is one instance of this class for each renderer channel (same as for
// the PluginDispatchers).
-class PluginMessageFilter : public IPC::ChannelProxy::MessageFilter,
- public IPC::Sender {
+class PPAPI_PROXY_EXPORT PluginMessageFilter
+ : public IPC::ChannelProxy::MessageFilter,
+ public IPC::Sender {
public:
- // The input is a pointer to a set that will be used to uniquify PP_Instances
- // across all renderer channels. The same pointer should be passed to each
- // MessageFilter to ensure uniqueness, and the value should outlive this
- // class.
- PluginMessageFilter(std::set<PP_Instance>* seen_instance_ids);
+ // |seen_instance_ids| is a pointer to a set that will be used to uniquify
+ // PP_Instances across all renderer channels. The same pointer should be
+ // passed to each MessageFilter to ensure uniqueness, and the value should
+ // outlive this class. It could be NULL if this filter is for a browser
+ // channel.
+ // |thread_registrar| is used to look up handling threads for resource
+ // reply messages. It shouldn't be NULL.
+ PluginMessageFilter(
+ std::set<PP_Instance>* seen_instance_ids,
+ scoped_refptr<ResourceReplyThreadRegistrar> thread_registrar);
virtual ~PluginMessageFilter();
// MessageFilter implementation.
@@ -38,14 +49,30 @@ class PluginMessageFilter : public IPC::ChannelProxy::MessageFilter,
// IPC::Sender implementation.
virtual bool Send(IPC::Message* msg) OVERRIDE;
+ // Simulates an incoming resource reply that is handled on the calling thread.
+ // For testing only.
+ static void DispatchResourceReplyForTest(
+ const ResourceMessageReplyParams& reply_params,
+ const IPC::Message& nested_msg);
+
private:
void OnMsgReserveInstanceId(PP_Instance instance, bool* usable);
+ void OnMsgResourceReply(const ResourceMessageReplyParams& reply_params,
+ const IPC::Message& nested_msg);
- // All instance IDs every queried by any renderer on this plugin. This is
- // used to make sure that new instance IDs are unique. This is a non-owning
- // pointer, it will be managed by the later that creates this class.
+ // Dispatches the given resource reply to the appropriate resource in the
+ // plugin process.
+ static void DispatchResourceReply(
+ const ResourceMessageReplyParams& reply_params,
+ const IPC::Message& nested_msg);
+
+ // All instance IDs ever queried by any renderer on this plugin. This is used
+ // to make sure that new instance IDs are unique. This is a non-owning
+ // pointer. It is managed by PluginDispatcher::PluginDelegate.
std::set<PP_Instance>* seen_instance_ids_;
+ scoped_refptr<ResourceReplyThreadRegistrar> resource_reply_thread_registrar_;
+
// The IPC channel to the renderer. May be NULL if we're not currently
// attached as a filter.
IPC::Channel* channel_;